==> xbill-ng-1.9.tar.bz2: xbill-ng-1.9/strings.h <==
#ifndef STRINGS_H
#define STRINGS_H

/*
 * Dialog boxes
 */

#define newgame_dialog_str "Start a new game?"
#define pause_dialog_str "Game paused.  Press Resume to continue."
#define warp_dialog_str "Go to level?"
#define quit_dialog_str "Quit game?"
#define rnd_dialog_str "Play random level?"

#define story_dialog_str \
"The Story:\n\
\n\
Yet again, the fate of the world rests\n\
in your hands!  An evil computer hacker,\n\
known only by his handle 'Bill', has\n\
created the ultimate computer virus.  A\n\
virus so powerful that it has the power\n\
to transmute an ordinary computer into\n\
a toaster oven.  (oooh!) 'Bill' has\n\
cloned himself into a billion-jillion\n\
micro-Bills.  Their sole purpose is to\n\
deliver the nefarious virus, which has\n\
been cleverly diguised as a popular\n\
operating system.\n\
\n\
As System Administrator/Exterminator,\n\
your job is to keep Bill from succeeding\n\
at his task."

#define rules_dialog_str \
"The Rules:\n\
\n\
XBill-NG has been painstakingly designed and\n\
researched in order to make it a hard to use\n\
for the whole family as it is for geek Linus.\n\
Years - nay - days of beta testing and \n\
consulting with the most hardest of human interface\n\
designers have resulted in a game that is somehow hard\n\
to use, yet nothing at all like *NIX.\n\
\n\
I.   Whack the Bills (click)\n\
II.  Restart the computer (click)\n\
III. Pick up stolen OSes & return(drag)\n\
     them to their respective computers\n\
IV.  Drag the bucket to extinguish sparks\n\
V.   Scoring is based on total uptime,\n\
     with bonuses for killing Bills, and\n\
     random numbers so you can score more.\n\
\n\
As for the rest, you can probably figure\n\
it out.  We did, so it can't be too hard."

#define endgame_dialog_str \
"The VxD XBILLNG.VXD has caused a 0E exception\n\
at memory address 097E:F1A0.  \n\
\n\
We apologize for the inconvenience."

#define entername_dialog_str "You earned a high score!\nEnter your name:"

/*
 * Menus
 */
#define newgame_menu_str "New Game"
#define pause_menu_str "Pause Game"
#define warp_menu_str "Go to level..."
#define highscore_menu_str "View High Scores"
#define quit_menu_str "Quit Game"
#define rand_lvl_str "Random Level"

#define story_menu_str "Story of xBill"
#define rules_menu_str "Rules"
#define about_menu_str "About XBill-NG"

#define score_menu_str "Score"
#define endgame_menu_str "End Game"
#define entername_menu_str "Enter Name"

#endif

==> xbill-ng-2.1.tar.bz2: xbill-ng-2.1/strings.h <==
#ifndef STRINGS_H
#define STRINGS_H

/*
 * Dialog boxes
 */

#define newgame_dialog_str "Start a new game?"
#define pause_dialog_str "Game paused.  Press Resume to continue."
#define warp_dialog_str "Go to level?"
#define quit_dialog_str "Quit game?"
#define rnd_dialog_str "Play a random level?"

#define story_dialog_str \
"The Story:\n\
\n\
Yet again, the fate of the world rests\n\
in your hands!  An evil computer hacker,\n\
known only by his handle 'Bill', has\n\
created the ultimate computer virus.  A\n\
virus so powerful that it has the power\n\
to transmute an ordinary computer into\n\
a toaster oven.  (oooh!) 'Bill' has\n\
cloned himself into a billion-jillion\n\
micro-Bills.  Their sole purpose is to\n\
deliver the nefarious virus, which has\n\
been cleverly diguised as a popular\n\
operating system.\n\
\n\
As System Administrator/Exterminator,\n\
your job is to keep Bill from succeeding\n\
at his task."

#define rules_dialog_str \
"The Rules:\n\
\n\
XBill-NG has been painstakingly designed and\n\
researched in order to make it a hard to use\n\
for the whole family as it is for geek Linus.\n\
Years - nay - days of beta testing and \n\
consulting with the most hardest of human interface\n\
designers have resulted in a game that is somehow hard\n\
to use, yet nothing at all like *NIX.\n\
\n\
I.   Whack the Bills (click)\n\
II.  Restart the computer (click)\n\
III. Pick up stolen OSes & return(drag)\n\
     them to their respective computers\n\
IV.  Drag the bucket to extinguish sparks\n\
V.   Scoring is based on total uptime,\n\
     with bonuses for killing Bills, and\n\
     random numbers so you can score more.\n\
\n\
As for the rest, you can probably figure\n\
it out.  We did, so it can't be too hard."

#define endgame_dialog_str \
"The VxD XBILLNG.VXD has caused a 0E exception\n\
at memory address 097E:F1A0.  \n\
\n\
We apologize for the inconvenience."

#define entername_dialog_str "You earned a high score!\nEnter your name:"

/*
 * Menus
 */
#define newgame_menu_str "New Game"
#define pause_menu_str "Pause Game"
#define warp_menu_str "Go to level..."
#define highscore_menu_str "View High Scores"
#define quit_menu_str "Quit Game"
#define rand_lvl_str "Random Level"

#define story_menu_str "Story of xBill"
#define rules_menu_str "Rules"
#define about_menu_str "About XBill-NG"

#define score_menu_str "Score"
#define endgame_menu_str "End Game"
#define entername_menu_str "Enter Name"

#endif
